@@ -1,9 +1,8 @@
 import os
 import platform
+from textwrap import dedent
 from unittest import TestCase
 
-import tomlkit
-
 from semantic_release.errors import ImproperConfigurationError
 from semantic_release.history import parser_angular
 from semantic_release.settings import _config, current_commit_parser
@@ -90,6 +89,27 @@ foo = "bar"
         # delete temporary toml config file
         os.remove(dummy_conf_path)
 
+    @mock.patch("semantic_release.settings.getcwd", return_value=temp_dir)
+    def test_toml_no_psr_section(self, mock_getcwd):
+        # create temporary toml config file
+        dummy_conf_path = os.path.join(temp_dir, "pyproject.toml")
+        toml_conf_content = dedent(
+            """
+            [tool.foo]
+            bar = "baz"
+            """
+        )
+        os.makedirs(os.path.dirname(dummy_conf_path), exist_ok=True)
+
+        with open(dummy_conf_path, "w") as dummy_conf_file:
+            dummy_conf_file.write(toml_conf_content)
+
+        config = _config()
+        mock_getcwd.assert_called_once_with()
+        self.assertEqual(config.get("hvcs"), "github")
+        # delete temporary toml config file
+        os.remove(dummy_conf_path)
+
     @mock.patch("semantic_release.settings.config.get", lambda *x: "nonexistent.parser")
     def test_current_commit_parser_should_raise_error_if_parser_module_do_not_exist(
         self,
